Upgrading to Newer Releases
===========================

Choppy itself is changing like any software is changing over time.  Most of
the changes are the nice kind, the kind where you don't have to change
anything in your config/code to profit from a new release.

However every once in a while there are changes that do require some
changes in your config/code or there are changes that make it possible
for you to improve your own code quality by taking advantage of new
features in Choppy.

This section of the documentation enumerates all the changes in Choppy from
release to release and how you can change your code/config to have a painless
updating experience.
